@@ -2,7 +2,9 @@
 # -*- coding: utf-8 -*-
 
 # Other libraries
+import h5py
 import click
+import psutil
 import numpy as np
 from numba import jit
 from tqdm import trange
@@ -384,21 +386,95 @@ def gauss(series) -> None:
     if not series.potency:
         potency(series)
     bins = np.array(series.bins)
-    z2n = np.array(series.z2n)
-    mean = sum(bins * z2n) / sum(z2n)
-    sigma = np.sqrt(sum(z2n * (bins - mean) ** 2) / sum(z2n))
+    pot = np.array(series.z2n)
+    mean = sum(bins * pot) / sum(pot)
+    sigma = np.sqrt(sum(pot * (bins - mean) ** 2) / sum(pot))
     guess = [series.potency, mean, sigma]
-    popt, _ = optimize.curve_fit(gaussian, bins, z2n, guess)
+    popt, pcov = optimize.curve_fit(gaussian, bins, pot, guess)
     series.frequency = np.absolute(popt[1])
     series.error = np.absolute(popt[2])
     period(series)
     series.noise = np.absolute(
         (1 / (series.frequency + series.error)) - series.period)
-    lower = series.frequency - series.error
-    upper = series.frequency + series.error
-    low = np.where(np.isclose(bins, lower, 0.1))[0][0]
-    up = np.where(np.isclose(bins, upper, 0.1))[0][-1]
+    # lower = series.frequency - series.error
+    # upper = series.frequency + series.error
+    # low = np.where(np.isclose(bins, lower, 0.1))[0][0]
+    # up = np.where(np.isclose(bins, upper, 0.1))[0][-1]
     # series.z2n[low:up] = gaussian(bins[low:up], *popt)
     # plt.plot(bins[low:up], gaussian(bins[low:up], *popt), color='red')
     del bins
-    del z2n
+    del pot
+
+
+def crop(series, temp) -> int:
+    """
+    Crop and recalculate periodogram region.
+
+    Parameters
+    ----------
+    series : Series
+        A time series object.
+
+    Returns
+    -------
+    None
+    """
+    flag = 0
+    click.secho("This will recalculate the periodogram.", fg='yellow')
+    flag2 = True
+    while flag2:
+        if click.confirm("Is the region selected"):
+            axis = plt.gca().get_xlim()
+            low = np.where(np.isclose(series.bins, axis[0], 0.1))
+            up = np.where(np.isclose(series.bins, axis[1], 0.1))
+            low = np.rint(np.median(low)).astype(int)
+            up = np.rint(np.median(up)).astype(int)
+            temp.fmin = axis[0]
+            temp.fmax = axis[1]
+            temp.set_delta()
+            block = (temp.fmax - temp.fmin) / np.array(temp.delta)
+            nbytes = np.array(temp.delta).dtype.itemsize * block
+            click.secho(
+                f"Computation memory {nbytes * 10e-6} MB", fg='yellow')
+            if click.confirm("Run the program with these values"):
+                if nbytes < psutil.virtual_memory()[1]:
+                    temp.bins = np.arange(temp.fmin, temp.fmax, temp.delta)
+                    click.secho('Frequency bins set.', fg='green')
+                    temp.get_bins()
+                    temp.time = series.time
+                    plt.close()
+                    temp.set_periodogram()
+                    size = (series.bins.size - (up - low)) + temp.bins.size
+                    middle = low + temp.bins.size
+                    tempx = np.zeros(size)
+                    tempy = np.zeros(size)
+                    tempx[:low] = series.bins[:low]
+                    tempy[:low] = series.z2n[:low]
+                    tempx[low:middle] = temp.bins
+                    tempy[low:middle] = temp.z2n
+                    tempx[middle:] = series.bins[up:]
+                    tempy[middle:] = series.z2n[up:]
+                    series.bins = tempx
+                    series.z2n = tempy
+                    series.set_bak()
+                    # series.get_bak()
+                    series.bak = h5py.File(series.bak, 'a')
+                    series.bak.create_dataset(
+                        'FREQUENCY', data=series.bins, compression='lzf')
+                    series.bak.create_dataset(
+                        'POTENCY', data=series.z2n, compression='lzf')
+                    series.bins = series.bak['FREQUENCY']
+                    series.z2n = series.bak['POTENCY']
+                    del temp
+                    del tempx
+                    del tempy
+                    flag = 0
+                    flag2 = False
+                else:
+                    click.secho("Not enough memory available.", fg='red')
+                    flag = 1
+            else:
+                flag = 1
+        else:
+            flag = 1
+    return flag
